# App::hopen::T::Gnu - GNU toolset
package App::hopen::T::Gnu;
use Data::Hopen;
use Data::Hopen::Base;

our $VERSION = '0.000010';

#use parent 'Data::Hopen::TODO';
#use Class::Tiny qw(TODO);

# Docs {{{1

=head1 NAME

Data::Hopen::T::Gnu - GNU toolset for hopen

=head1 SYNOPSIS

This toolset supports any compiler that will accept gcc(1) options, and any
linker that will accept GNU ld(1) options.

=cut

# }}}1

1;
__END__
# vi: set fdm=marker: #
